==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Outils de bloc</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Voir les outils de bloc</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Bloc</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Données du bloc</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nom du Bloc :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaces avant ou après.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nom du bloc est vide.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nom du bloc n&apos;est pas valide.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; existe&lt;br&gt;et sera écrasé.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Bloc existe déjà.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Outils de bloc</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Voir les outils de bloc</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;Bloc</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Données du bloc</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Nom du Bloc :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>block 1</translation>
    </message>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaces avant ou après.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Nom du bloc est vide.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Nom du bloc n&apos;est pas valide.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Block &quot;%1&quot; existe&lt;br&gt;et sera écrasé.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Bloc existe déjà.</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Présentation</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Espaces avant ou après.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">Nom du présentation est vide.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">Nom du présentation n&apos;est pas valide.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Présentation &quot;%1&quot; existe&lt;br&gt;et sera écrasé.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">Présentation existe déjà.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Données du présentation</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Nom du présentation :</translation>
    </message>
</context>
</TS>
